%define oname		guile

%define major		17
%define libname		%mklibname %{oname} %{major}
%define develname	%mklibname %{oname}1.8 -d

%define api 1.8
%define mver 1.8

%global __requires_exclude devel\\(libguile\\)
%global __provides_exclude_from lib%{oname}-srfi-.\\+\\.so$
%global __requires_exclude_from lib%{oname}-srfi-.\\+\\.so$

%define _requires_exceptions devel(.*)

Name:		guile%{mver}
Version:	1.8.8
Release:	%mkrel 6
Summary:	GNU implementation of Scheme for application extensibility
License:	LGPLv2+
Group:		Development/Other
URL:		http://www.gnu.org/software/guile/guile.html
Source0:	ftp://ftp.gnu.org/pub/gnu/guile/guile-%{version}.tar.xz
Patch0:		guile-1.8.3-64bit-fixes.patch
Patch1:		guile-1.6.4-amd64.patch
Patch2:		guile-1.8.5-drop-ldflags-from-pkgconfig.patch
Patch3:		guile-1.8.7-testsuite.patch
Patch5:		guile-1.8.7-fix-doc.patch
Patch7:		guile-1.8.8-automake-1.13.patch
Requires(post):	%{libname} = %{version}-%{release}
Requires(post):	rpm-helper
Requires(preun): rpm-helper
BuildRequires:	chrpath
BuildRequires:	libgmp-devel
BuildRequires:	libltdl-devel
BuildRequires:	libncurses-devel
BuildRequires:	libreadline-devel
BuildRequires:	gettext-devel
# for srfi-19.test
BuildRequires:	timezone
Obsoletes:	%{oname} < 1.8.8-4
Conflicts:	%{oname} >= 2.0.3

%package -n %{libname}
Summary:	Libraries for Guile %{version}
Group:		System/Libraries
Requires:	%{name}-runtime = %{version}-%{release}

%package -n %{develname}
Summary:	Development headers and static library for libguile
Group:		Development/Libraries
Requires:	%{libname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{_lib}%{oname}-devel < 1.8.8-4
Obsoletes:	%{_lib}%{oname}17-devel
Conflicts:	%{_lib}%{oname}-devel >= 2.0.3

%package runtime
Summary:	Guile runtime library
Group:		System/Libraries


%description
GUILE (GNU's Ubiquitous Intelligent Language for Extension) is a
library implementation of the Scheme programming language, written in
C. GUILE provides a machine-independent execution platform that can
be linked in as a library during the building of extensible programs.

Install the guile package if you'd like to add extensibility to
programs that you are developing. You'll also need to install the
guile-devel package.

%description -n %{libname}
This package contains Guile shared object libraries. Guile is the GNU
Ubiquitous Intelligent Language for Extension.

%description -n %{develname}
This package contains the development headers and the static library
for libguile. C headers, aclocal macros, the `guile1.4-snarf' and
`guile-config' utilities, and static `libguile' library for Guile, the
GNU Ubiquitous Intelligent Language for Extension

%description runtime
This package contains Scheme runtime for GUILE, including ice-9
Scheme module.

%prep
%setup -q -n %{oname}-%{version}
%patch0 -p1 -b .64bit-fixes
%patch1 -p1 -b .amd64
%patch2 -p0 -b .pkgconfig
%patch3 -p1 -b .testsuite

%patch5 -p1 -b .doc
%patch7 -p1
chmod +x scripts/snarf-check-and-output-texi

%build
autoreconf -vfi
%configure2_5x \
    --disable-error-on-warning \
    --disable-rpath \
    --enable-dynamic-linking \
    --with-threads \
    --disable-static

%make

%check
# There was a hack, now broken to make it generated before running the tests
# Patch8 drops the hack so we need to build the file
make -C libguile stack-limit-calibration.scm


%install
rm -rf %buildroot
%makeinstall_std

%{__mkdir_p} %{buildroot}%{_datadir}/%{oname}/site

%multiarch_includes %{buildroot}%{_includedir}/lib%{oname}/scmconfig.h

%{_bindir}/chrpath -d %{buildroot}{%{_bindir}/%{oname},%{_libdir}/*.so.*.*.*}

#for ghost files
touch %{buildroot}%{_datadir}/%{oname}/%{api}/slibcat
touch %{buildroot}%{_datadir}/%{oname}/%{api}/slib


rm -f ${RPM_BUILD_ROOT}%{_libdir}/libguile*.la

%post
%_install_info %{oname}-tut.info
%_install_info %{oname}.info
%_install_info r5rs.info
%_install_info goops.info

%preun
%_remove_install_info %{oname}-tut.info
%_remove_install_info %{oname}.info
%_remove_install_info r5rs.info
%_remove_install_info goops.info

%triggerin -- slib
# Remove files created in guile < 1.8.7-4mdv
ln -sfT ../../slib %{_datadir}/guile/%{mver}/slib

rm -f %{_datadir}/guile/%{mver}/slibcat
export SCHEME_LIBRARY_PATH=%{_datadir}/slib/

# Build SLIB catalog
for pre in \
    "(use-modules (ice-9 slib))" \
    "(load \"%{_datadir}/slib/guile.init\")"
do
    %{_bindir}/guile -c "$pre
        (set! implementation-vicinity (lambda () \"%{_datadir}/guile/%{mver}/\"))
        (require 'new-catalog)" &> /dev/null && break
    rm -f %{_datadir}/guile/%{mver}/slibcat
done
:

%triggerun -- slib
if [ "$1" = 0 -o "$2" = 0 ]; then
    rm -f %{_datadir}/guile/%{mver}/slib{,cat}
fi


%files
%doc AUTHORS ChangeLog GUILE-VERSION LICENSE README THANKS
%{_bindir}/%{oname}
%{_bindir}/%{oname}-tools
%exclude %{_datadir}/%{oname}/%{mver}
%{_mandir}/man1/guile.1.*
%{_infodir}/*


%files -n %{libname}
%{_libdir}/lib*.so.%{major}*
%{_libdir}/lib%{oname}-srfi-srfi-13-14-v-3.so.3*
%{_libdir}/lib%{oname}-srfi-srfi-4-v-3.so.3*
%{_libdir}/lib%{oname}-srfi-srfi-1-v-3.so.3*
%{_libdir}/lib%{oname}-srfi-srfi-60-v-2.so.2*

%files -n %{develname}
%doc ABOUT-NLS HACKING NEWS INSTALL libguile/ChangeLog*
%multiarch %{multiarch_includedir}/lib%{oname}/scmconfig.h
%{_bindir}/%{oname}-config
%{_bindir}/%{oname}-snarf
%{_datadir}/aclocal/*
%{_includedir}/lib%{oname}*
%{_includedir}/%{oname}*
%{_libdir}/libguile.so
%{_libdir}/pkgconfig/%{oname}*.pc

%files runtime
%{_datadir}/%{oname}/%{mver}/*
%ghost %{_datadir}/%{oname}/%{api}/slibcat
%ghost %{_datadir}/%{oname}/%{api}/slib
%{_libdir}/libguilereadline-v-%{major}.so
%{_libdir}/libguile-srfi-srfi-60-v-2.so
%{_libdir}/libguile-srfi-srfi-4-v-3.so
%{_libdir}/libguile-srfi-srfi-13-14-v-3.so
%{_libdir}/libguile-srfi-srfi-1-v-3.so


%changelog
* Fri Oct 23 2015 bb <bb> 1.8.8-6pclos2015
- keep trying to fix specfile

* Fri Oct 23 2015 bb <bb> 1.8.8-5pclos2015
- keep trying to fix specfile

* Thu Oct 22 2015 bb <bb> 1.8.8-4pclos2015
- fix specfile

* Thu Oct 22 2015 bb <bb> 1.8.8-3pclos2015
- update based partially on mga specfile
